==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapPermissionTicketEntityFieldDelegate.java <==
package org.keycloak.models.map.authorization.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapPermissionTicketEntityFieldDelegate extends org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity.AbstractMapPermissionTicketEntity implements org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> entityFieldDelegate;
    public MapPermissionTicketEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getOwner() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.OWNER);
    }
    @SuppressWarnings("unchecked") @Override public void setOwner(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.OWNER, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRequester() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REQUESTER);
    }
    @SuppressWarnings("unchecked") @Override public void setRequester(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REQUESTER, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getCreatedTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.CREATED_TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setCreatedTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.CREATED_TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getGrantedTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.GRANTED_TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setGrantedTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.GRANTED_TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getScopeId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.SCOPE_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setScopeId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.SCOPE_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceServerId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_SERVER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceServerId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_SERVER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getPolicyId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.POLICY_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setPolicyId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.POLICY_ID, p0);
    }
}

==> keycloak-model-map-22.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapPermissionTicketEntityFieldDelegate.java <==
package org.keycloak.models.map.authorization.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapPermissionTicketEntityFieldDelegate extends org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity.AbstractMapPermissionTicketEntity implements org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> entityFieldDelegate;
    public MapPermissionTicketEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void markUpdatedFlag() {
        entityFieldDelegate.markUpdatedFlag();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @Override public String toString() {
        return "%" + String.valueOf(entityFieldDelegate);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getOwner() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.OWNER);
    }
    @SuppressWarnings("unchecked") @Override public void setOwner(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.OWNER, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRequester() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REQUESTER);
    }
    @SuppressWarnings("unchecked") @Override public void setRequester(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.REQUESTER, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getCreatedTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.CREATED_TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setCreatedTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.CREATED_TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getGrantedTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.GRANTED_TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setGrantedTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.GRANTED_TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getScopeId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.SCOPE_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setScopeId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.SCOPE_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceServerId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_SERVER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceServerId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.RESOURCE_SERVER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getPolicyId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.POLICY_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setPolicyId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntityFields.POLICY_ID, p0);
    }
}
